===============================
 Flask-IIIF v0.1.0 is released
===============================

Flask-IIIF v0.1.0 was released on April 28, 2015.

About
-----

Flask-IIIF is a Flask extension permitting easy integration with the
International Image Interoperability Framework (IIIF) API standards.

What's new
----------

- Initial public release.

Installation
------------

   $ pip install Flask-IIIF

Documentation
-------------

   http://flask-iiif.readthedocs.org/en/v0.1.0

Homepage
--------

   https://github.com/inveniosoftware/flask-iiif

Good luck and thanks for choosing Flask-IIIF.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: http://github.com/inveniosoftware
|   URL: http://invenio-software.org
